Interface ResultSetMapper<T>

Type Parameters:
T - generic type param of the resulting type
Functional Interface:
This is a functional interface and can therefore be used as the assignment target for a lambda expression or method reference.

@FunctionalInterface public interface ResultSetMapper<T>
Component capable of mapping ResultSet to e.g. POJO.
  • Method Summary

    Modifier and Type
    Method
    Description
    Maps a sql result set into a object.
  • Method Details

    • mapResultSet

      T mapResultSet(ResultSet resultSet) throws Exception
      Maps a sql result set into a object.
      Parameters:
      resultSet - containing columns of a row
      Returns:
      result
      Throws:
      Exception - if something went wrong