All Classes and Interfaces
Class
Description
Represent a column and its value into a JDBC prepared statement.
A ConnectionFactory combines a set of connection configuration
parameters that have been defined prior to connection creation.
A DataSource utilizing a
ConnectionFactory.The ConnectionPool maintains a cache of reusable
Connections.A DataSource backed by a
ConnectionPool.Converts a
Criterion into a WhereClause that sql requires in order to perform queries against
its backend.Component that can translate a canonical field path into a sql column name or path.
Global, domain-agnostic Postgres statements, operators, functions, clauses, etc.
Postgresql's implementation of the operator translator
Provides query capabilities to stores
Component capable of mapping
ResultSet to e.g.Implementation of the
SortFieldConverter.Helps in constructing SQL insert/update statements without having to deal with the SQL syntax directly
Represent a SQL operator
Translate domain representation of an operator into its SQL representation
The SqlQueryExecutor is capable of executing parametrized SQL queries
Configuration class for
SqlQueryExecutorMaps a
QuerySpec to a single SQL SELECT ... FROM ... WHERE ... statement.Provide base SQL functionalities.
A TranslationMapping keeps a tree of
FieldTranslators that can be obtained using canonical
information about business objects to SQL, i.e.Represent a where condition clause in a prepared statement, like "column_table = ?"