All Classes and Interfaces
Class
Description
Represent a column and its value into a JDBC prepared statement.
A ConnectionFactory combines a set of connection configuration
parameters that have been defined prior to connection creation.
A DataSource utilizing a
ConnectionFactory.The ConnectionPool maintains a cache of reusable
Connections.A DataSource backed by a
ConnectionPool.Global, domain-agnostic Postgres statements, operators, functions, clauses, etc.
Provides query capabilities to stores
Component capable of mapping
ResultSet to e.g.Parses a
Criterion and provides methods to validate it and extract SQL prepared statement placeholders and
parameters.Helps in constructing SQL insert/update statements without having to deal with the SQL syntax directly
The SqlQueryExecutor is capable of executing parametrized SQL queries
Configuration class for
SqlQueryExecutorMaps a
QuerySpec to a single SQL SELECT ... FROM ... WHERE ... statement.Provide base SQL functionalities.
A TranslationMapping maps canonical information about business objects to SQL, i.e.