All Classes and Interfaces
Class
Description
Global, domain-agnostic and generic SQL statements, operators, functions, clauses, etc.
A ConnectionFactory combines a set of connection configuration
parameters that have been defined prior to connection creation.
A DataSource utilizing a
ConnectionFactory.The ConnectionPool maintains a cache of reusable
Connections.A DataSource backed by a
ConnectionPool.Global, domain-agnostic Postgres statements, operators, functions, clauses, etc.
Provides query capabilities to stores
Component capable of mapping
ResultSet to e.g.Parses a
Criterion and provides methods to validate it and extract SQL prepared statement placeholders and
parameters.The SqlQueryExecutor is capable of executing parametrized SQL queries
Configuration class for
SqlQueryExecutorMaps a
QuerySpec to a single SQL SELECT ... FROM ... WHERE ... statement.A TranslationMapping maps canonical information about business objects to SQL, i.e.